@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 * Copyright (c) 2010 Ruslan Kabatsayev <b7.10110111@gmail.com>
 *
 * based on the Null Theme Engine for Gtk+.
@@ -25,7 +25,7 @@
 #include <gtk/gtk.h>
 #include <dlfcn.h>
 #include <string>
-#include "oxygen_version.h"
+#include "oxygenversion.h"
 
 enum WinDecoOptions
 {
@@ -232,7 +232,7 @@ gboolean on_expose(GtkWidget* mw0, GdkEventExpose* event, gpointer user_data)
             int buttonSize=getWindecoButtonSize(type);
             int buttonSpacing=getWindecoMetric(ButtonSpacing);
             int dbut=buttonSize+buttonSpacing;
-            drawWindecoButton(cr, type, status, opt, 
+            drawWindecoButton(cr, type, status, opt,
                     mw0->allocation.width-shadowRight-borderRight-buttonSize-buttonSize*type,
                     status*dbut+shadowTop+(borderTop-buttonSize)/2,
                     buttonSize, buttonSize);
@@ -301,7 +301,16 @@ gboolean on_configure0(GtkWidget* mw0, GdkEventConfigure* event, gpointer user_d
 }
 
 //___________________________________________________________________
-int main(int argc, char** argv)
+gboolean on_press0(GtkWindow* window, GdkEventButton* event, GdkWindowEdge edge)
+{
+    if(event->type == GDK_BUTTON_PRESS)
+        if(event->button == 1)
+            gtk_window_begin_move_drag(window,event->button,event->x_root,event->y_root,event->time);
+    return FALSE;
+}
+
+//___________________________________________________________________
+int main( int argc, char** argv )
 {
 
     // load methods from style library
@@ -310,7 +319,33 @@ int main(int argc, char** argv)
     // initialize gtk
     gtk_init(&argc, &argv);
 
-    processCommandLine(argc,argv);
+    // command line arguments
+    gboolean version( FALSE );
+    GOptionEntry entries[] =
+    {
+        { "version", 'v', 0, G_OPTION_ARG_NONE, &version, "Show the application's version", 0L },
+        { 0L }
+    };
+
+    GError *error = 0L;
+    GOptionContext* context( g_option_context_new( "- Gtk+ widgets preview for oxygen" ) );
+    g_option_context_add_main_entries(context, entries, 0L );
+    g_option_context_add_group (context, gtk_get_option_group( TRUE ) );
+    g_option_context_parse( context, &argc, &argv, &error );
+    g_option_context_free( context );
+
+    if( version )
+    {
+        /*
+        HACK: need to create (and destroy immediatly) a dummy window
+        in order to make sure that the widget style is initialized properly
+        */
+        GtkWidget* window = gtk_window_new( GTK_WINDOW_TOPLEVEL );
+        gtk_widget_destroy( window );
+
+        Oxygen::Version::print();
+        return 0;
+    }
 
     // draw
     mw0=gtk_window_new(GTK_WINDOW_TOPLEVEL);
@@ -325,12 +360,14 @@ int main(int argc, char** argv)
     gtk_window_set_default_size( GTK_WINDOW(mw1), ww, wh );
     gtk_window_set_default_size( GTK_WINDOW(mw0), ww+dw, wh+dh );
     gtk_window_set_decorated(GTK_WINDOW(mw0), FALSE);
+    gtk_widget_add_events(mw0,GDK_BUTTON_PRESS_MASK);
 
     gtk_window_set_title( GTK_WINDOW(mw1), "This is a caption");
 
     g_signal_connect( G_OBJECT(mw0), "expose-event", G_CALLBACK(on_expose), 0L);
     g_signal_connect( G_OBJECT(mw1), "configure-event", G_CALLBACK(on_configure1), 0L);
     g_signal_connect( G_OBJECT(mw0), "configure-event", G_CALLBACK(on_configure0), 0L);
+    g_signal_connect( G_OBJECT(mw0), "button-press-event", G_CALLBACK(on_press0), NULL);
 
     gtk_widget_show( mw1 );
     gtk_widget_show( mw0 );
