@@ -2,7 +2,7 @@
 #define oxygenmenustateengine_h
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -116,6 +116,10 @@ namespace Oxygen
             return true;
         }
 
+        //! update state for given widget
+        bool updateState( GtkWidget* parent, GtkWidget* child, bool state, bool delayed = false )
+        { return data().value( parent ).updateState( child, state, delayed ); }
+
         //@}
 
         //!@name accessors
