@@ -2,7 +2,7 @@
 #define oxygenscrollbardata_h
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -34,16 +34,10 @@ namespace Oxygen
         public:
 
         //! constructor
-        ScrollBarData( void ):
-            _target( 0L ),
-            _updatesDelayed( false ),
-            _delay( 10 ),
-            _locked( false )
-        {}
+        ScrollBarData( void );
 
         //! destructor
-        virtual ~ScrollBarData( void )
-        { disconnect( _target ); }
+        virtual ~ScrollBarData( void );
 
         //! setup connections
         void connect( GtkWidget* );
@@ -51,14 +45,6 @@ namespace Oxygen
         //! disconnect
         void disconnect( GtkWidget* );
 
-        //! toggle delayed updates
-        void setUpdatesDelayed( bool value )
-        { _updatesDelayed = value; }
-
-        //! set delay
-        void setDelay( int value )
-        { _delay = value; }
-
         protected:
 
         static void valueChanged( GtkRange*, gpointer );
