@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * inspired notably from kdelibs/kdeui/color/kcolorutils.h
 * Copyright (C) 2007 Matthew Woehlke <mw_triad@users.sourceforge.net>
@@ -64,58 +64,36 @@ namespace Oxygen
             pidAppName=envAppName;
         }
 
-        if( pidAppName == "opera" ) _name = Opera;
-        else if( gtkAppName == "eclipse" || gtkAppName == "Eclipse" ) _name = Eclipse;
-        else if( pidAppName == "java" ) {
+        // tag all mozilla-like applications (XUL)
+        static const std::string XulAppNames[] =
+        {
+            "firefox",
+            "thunderbird",
+            "seamonkey",
+            "iceweasel",
+            "icecat",
+            "icedove",
+            "xulrunner",
+            "komodo",
+            "aurora",
+            "zotero",
+            ""
+        };
 
-            if( !( gtkAppName.empty() || gtkAppName == "<unknown>" ) ) _name = JavaSwt;
-            else _name = Java;
-
-        } else if( gtkAppName == "acroread" ) _name = Acrobat;
-        else if( gtkAppName == "soffice" ) _name = OpenOffice;
-        else if( gtkAppName == "gimp" ) _name = Gimp;
-        else if(
-            gtkAppName == "chrome" ||
-            gtkAppName == "chromium" ||
-            gtkAppName == "chromium-browser" ||
-            gtkAppName == "google-chrome" ) _name = GoogleChrome;
-        else {
-
-            // tag all mozilla-like applications (XUL)
-            static const std::string XulAppNames[] =
+        for( unsigned int index = 0; !XulAppNames[index].empty(); ++index )
+        {
+            if( gtkAppName.find( XulAppNames[index] ) == 0 || pidAppName.find( XulAppNames[index] ) == 0 )
             {
-                "firefox",
-                "thunderbird",
-                "seamonkey",
-                "iceweasel",
-                "icecat",
-                "icedove",
-                "xulrunner",
-                "komodo",
-                "aurora",
-                "zotero",
-                ""
-            };
-
-            for( unsigned int index = 0; !XulAppNames[index].empty(); ++index )
-            {
-                if( gtkAppName.find( XulAppNames[index] ) == 0 )
-                {
-                    _name = XUL;
-                    break;
-                }
+                _name = XUL;
+                break;
             }
         }
 
-        // For now, only LibreOffice passes its version, so for other apps version will remain NULL
-        _version=getenv("LIBO_VERSION");
-
         #if OXYGEN_DEBUG
         std::cerr << "ApplicationName::initialize -"
             << " from pid: " << pidAppName
             << " from gtk: " << gtkAppName
             << " internal: " << *this
-            << " version: " << (_version?_version:"0x0")
             << std::endl;
         #endif
 
@@ -125,6 +103,11 @@ namespace Oxygen
     //__________________________________________________________________________
     bool ApplicationName::isGtkDialogWidget( GtkWidget* widget ) const
     {
+
+        // check widget
+        if( !GTK_IS_WIDGET( widget ) ) return false;
+
+        // get parent
         GtkWidget* parent( gtk_widget_get_toplevel( widget ) );
 
         // check parent
@@ -136,12 +119,7 @@ namespace Oxygen
     {
 
         // check application name
-        if( !(
-            isXul() ||
-            isAcrobat() ||
-            isJavaSwt() ||
-            isGoogleChrome() ||
-            isEclipse() ) ) return false;
+        if( !isXul() ) return false;
 
         // check for Gtk dialog type
         if( widget && isGtkDialogWidget( widget ) ) return false;
@@ -169,19 +147,10 @@ namespace Oxygen
         // try read file
         std::ifstream in( filename.str().c_str() );
         if( !in ) return std::string();
-
-        /*
-        somehow std::getline gets some extra crap (non char) from the procfile
-        one has to use ifstream::getline, and pass it a fixed size line
-        */
-        char lineC[1024];
-        in.getline( lineC, 1024, '\n' );
-        std::string line( lineC );
-
-        // get position of last "/" character, and truncate accordingly
-        const size_t pos = line.rfind( '/' );
-        if( pos == std::string::npos ) return line;
-        else return line.substr( pos+1 );
+        std::string line;
+        std::getline( in, line, '\0' );
+        const size_t pos( line.rfind( '/' ) );
+        return ( pos == std::string::npos ) ? line:line.substr( pos+1 );
 
     }
 
@@ -192,15 +161,7 @@ namespace Oxygen
         {
             default:
             case Unknown: out << "Unknown"; break;
-            case Acrobat: out << "Acrobat"; break;
             case XUL: out << "XUL (Mozilla)"; break;
-            case Gimp: out << "Gimp"; break;
-            case OpenOffice: out << "OpenOffice"; break;
-            case GoogleChrome: out << "GoogleChrome"; break;
-            case Opera: out << "Opera"; break;
-            case Java: out << "Java"; break;
-            case JavaSwt: out << "JavaSwt"; break;
-            case Eclipse: out << "Eclipse"; break;
         }
 
         return out;
