@@ -36,15 +36,7 @@ namespace Oxygen
     enum AppName
     {
         Unknown,
-        Acrobat,
-        XUL,
-        Gimp,
-        OpenOffice,
-        GoogleChrome,
-        Opera,
-        Java,
-        JavaSwt,
-        Eclipse,
+        XUL
     };
 
     //! stores application name and provides some utility functions
@@ -55,8 +47,7 @@ namespace Oxygen
 
         //! constructor
         ApplicationName( AppName name = Unknown ):
-            _name( name ),
-            _version( NULL )
+            _name( name )
         {}
 
         //! assignment
@@ -70,9 +61,6 @@ namespace Oxygen
         operator const AppName& ( void ) const
         { return _name; }
 
-        const char* versionString( void ) const
-        { return _version; }
-
         //! initialize
         /*! try derive AppName from gtk program name */
         void initialize( void );
@@ -80,24 +68,12 @@ namespace Oxygen
         //!@name utilities
         //@{
 
-        bool isAcrobat( void ) const { return _name == Acrobat; }
         bool isXul( void ) const { return _name == XUL; }
-        bool isGimp( void ) const { return _name == Gimp; }
-        bool isOpenOffice( void ) const { return _name == OpenOffice; }
-        bool isGoogleChrome( void ) const { return _name == GoogleChrome; }
         bool isUnknown( void ) const { return _name == Unknown; }
 
-        bool isJava( void ) const { return _name == Java; }
-        bool isJavaSwt( void ) const { return _name == JavaSwt; }
-        bool isOpera( void ) const { return _name == Opera; }
-        bool isEclipse( void ) const { return _name == Eclipse; }
-
         //! special case for mozilla and acrobat that also check the type of the top level widget
         /*! this allows to prevent false positive for open and print dialogs */
-        bool isAcrobat( GtkWidget* widget ) const { return isAcrobat() && !isGtkDialogWidget( widget ); }
         bool isXul( GtkWidget* widget ) const { return isXul() && !isGtkDialogWidget( widget ); }
-        bool isJavaSwt( GtkWidget* widget ) const { return isJavaSwt() && !isGtkDialogWidget( widget ); }
-        bool isOpenOffice( GtkWidget* widget ) const { return isOpenOffice() && !isGtkDialogWidget( widget ); }
 
         // true for all applications that requires a flat background to be used
         bool useFlatBackground( GtkWidget* ) const;
@@ -120,8 +96,6 @@ namespace Oxygen
         //! name
         AppName _name;
 
-        const char* _version;
-
         //! streamer (for debugging)
         friend std::ostream& operator << ( std::ostream&, const ApplicationName& );
 
