@@ -2,7 +2,7 @@
 #define oxygengtktypenames_h
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * based on the Null Theme Engine for Gtk+.
 * Copyright (c) 2008 Robert Staudinger <robert.staudinger@gmail.com>
@@ -25,6 +25,7 @@
 
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
+#include <gio/gio.h>
 #include <string>
 #include <iostream>
 
@@ -80,6 +81,9 @@ namespace Oxygen
             //! icon size
             static const char* iconSize( GtkIconSize );
 
+            //! file monitor event
+            static const char* fileMonitorEvent( GFileMonitorEvent );
+
             //@}
 
             //__________________________________________
@@ -152,6 +156,7 @@ namespace Oxygen
             static GtkExpanderStyle	matchExpanderStyle( const char* );
             static GtkResponseType matchResponse( const char* );
             static GtkIconSize matchIconSize( const char* );
+            static GFileMonitorEvent matchFileMonitorEvent( const char* );
 
         };
     }
