@@ -644,21 +644,21 @@ namespace Oxygen
         switch( gtk_notebook_get_tab_pos( notebook ) )
         {
             case GTK_POS_BOTTOM:
-            rect->y += pageAllocation.height;
-            rect->height -= pageAllocation.height;
+            rect->height += rect->y - (pageAllocation.y + pageAllocation.height);
+            rect->y = pageAllocation.y + pageAllocation.height;
             break;
 
             case GTK_POS_TOP:
-            rect->height -= pageAllocation.height;
+            rect->height = pageAllocation.y - rect->y;
             break;
 
             case GTK_POS_RIGHT:
-            rect->x += pageAllocation.width;
-            rect->width -= pageAllocation.width;
+            rect->width += rect->x - (pageAllocation.x + pageAllocation.width);
+            rect->x = pageAllocation.x + pageAllocation.width;
             break;
 
             case GTK_POS_LEFT:
-            rect->width -= pageAllocation.width;
+            rect->width = pageAllocation.x - rect->x;
             break;
         }
 
@@ -763,7 +763,7 @@ namespace Oxygen
 
         // retrieve child
         GtkWidget* child( gtk_bin_get_child( GTK_BIN( widget ) ) );
-        if( GTK_IS_TREE_VIEW( child ) || GTK_IS_ICON_VIEW( child ) ) return true;
+        if( GTK_IS_TREE_VIEW( child ) || GTK_IS_ICON_VIEW( child ) || GTK_IS_TEXT_VIEW( child ) ) return true;
         else return false;
 
     }
