@@ -2,7 +2,7 @@
 #define oxygenstylehelper_h
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -192,6 +192,12 @@ namespace Oxygen
         CairoSurfaceCache<WindecoBottomBorderKey>& windecoBottomBorderCache( void )
         { return _windecoBottomBorderCache; }
 
+        //! shadow rendering
+        virtual void drawShadow( cairo_t*, const ColorUtils::Rgba&, int size ) const;
+
+        //! highlight glow
+        virtual void drawOuterGlow( cairo_t*, const ColorUtils::Rgba&, int size) const;
+
         //@}
 
         //@}
@@ -208,12 +214,6 @@ namespace Oxygen
         //! slab rendering
         virtual void drawSlab( Cairo::Context&, const ColorUtils::Rgba&, double shade) const;
 
-        //! shadow rendering
-        virtual void drawShadow( Cairo::Context&, const ColorUtils::Rgba&, int size ) const;
-
-        //! highlight glow
-        virtual void drawOuterGlow( Cairo::Context&, const ColorUtils::Rgba&, int size) const;
-
         //! inverse shadow (for sunken slabs)
         void drawInverseShadow( Cairo::Context&, const ColorUtils::Rgba&, int pad, int size, double fuzz ) const;
 
