@@ -3,7 +3,7 @@
 
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -21,6 +21,8 @@
 * MA 02110-1301, USA.
 */
 
+#include "oxygenwindecobutton.h"
+
 namespace Oxygen
 {
 
@@ -41,6 +43,30 @@ namespace Oxygen
         //! window decoration options
         typedef unsigned long Options;
 
+        enum Metric
+        {
+            BorderLeft=0,
+            BorderRight,
+            BorderBottom,
+            // BorderTop includes title and resize handle heights
+            BorderTop,
+            ButtonSpacing,
+            ButtonMarginTop,
+            ButtonMarginBottom,
+            ShadowLeft,
+            ShadowTop,
+            ShadowRight,
+            ShadowBottom,
+            MetricsCount
+        };
+
+        //! get frame dimensions
+        int getMetric(Metric wm);
+
+        //! get button size
+        // all buttons are of the same size in oxygen, so no argument in internal function
+        int getButtonSize();
+
     }
 
 }
